@@ -13,16 +13,16 @@
 
 package org.eclipse.linuxtools.systemtap.structures.tests;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import org.eclipse.linuxtools.systemtap.structures.IndexedObject;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 public class IndexedObjectTest{
 
-    @Before
+    @BeforeEach
     public void setUp() {
         one = new IndexedObject(1, "one");
         two = new IndexedObject(2, "two");
